@@ -6,7 +6,7 @@ from dataclasses import dataclass
 from huggingface_hub import login
 from diffusers import StableDiffusionPipeline, DPMSolverMultistepScheduler
 
-from multiskin_lib.src.multiskin.clean.clean_skin import clean_skin
+from src.multiskin.clean.clean_skin import clean_skin
 
 @dataclass
 class InferConfig:
